Task: Daily Dialog
===================
Description: A dataset of chitchat dialogues with strong annotations for topic, emotion and utterance act. This version contains both sides of every conversation, and uses the official train/valid/test splits from the original authors. See https://arxiv.org/abs/1710.03957 for more information.

Tags: #DailyDialog, #All, #ChitChat

